

# This MBARI Mapping AUV mission file has been generated
# by the MB-System program mbm_route2mission run by
# user <caress> on cpu <Ewing> at <Mon Nov 15 13:55:38 PST 2010>
# 
# Mission Summary:
#     Route File:               20101115_OaTest4v1.rte
#     Mission File:             20101115_OaTest4v1.cfg
#     Distance:                 1374.502675 (m)
#     Estimated Time:           2399 (s)  0.667 (hr)
#     Abort Time:               3119 (s)
#     Max battery life:         64800 (s)
#     Safety margin:            1800 (s)
#     Ascend time:              300 (s)
#     Way Points:               2
#     Route Points:             3
#     Survey behavior:          Waypoint
#     Descent style:            Waypoint descent
#     Mapping sonar control disabled:          
#     Benthic imaging camera control enabled:  
# 
# Mission Parameters:
#     Vehicle Survey Speed:     1.000000 (m/s) 1.943846 (knots)
#     Vehicle Ascent Speed:     1.500000 (m/s) 2.915769 (knots)
#     Vehicle Transit Speed:    1.500000 (m/s) 2.915769 (knots)
#     Desired Vehicle Altitude: 10 (m)
#     Minimum Vehicle Altitude: 20 (m)
#     Abort Vehicle Altitude:   3 (m)
#     Maximum Vehicle Depth:    112.970408 (m)
#     Abort Vehicle Depth:      122.970408 (m)
#     Descent Vehicle Depth:    3 (m)
#     Waypoint Spacing:         500 (m)
#     GPS Duration:             600 (s)
#     Descend Rate:             0.417 (m/s)
#     Ascend Rate:              1 (m/s)
#     Initial descend Duration: 300 (s)
#     Setpoint Duration:        30 (s)
# 
# The primary waypoints from the route file are:
#   <number> <longitude (deg)> <latitude (deg)> <topography (m)> <distance (m)> <type>
#   0 -121.850125 36.817944 -122.970408 0.000000 3
#   1 -121.834716 36.817854 -101.745921 1374.502675 4
# 
# A total of 3 mission points have been defined.
# 
# Define Mission parameters:
# 
#######################################################
# Set Mission Behaviors
# 
# mission timer set to 120% of estimated time of mission
behavior missionTimer
{
timeOut = 3119;
}
# 
# depth envelope
behavior depthEnvelope
{
minDepth = 0;
maxDepth = 60;
abortDepth = 63;
minAltitude = 20.000000;
abortAltitude = 3.000000;
}
#######################################################
# Set End-of-Mission Behaviors
# 
# 
# acquire gps fix 
behavior getgps
{
duration = 600;
minHits = 10;
abortOnTimeout = True;
}
# 
# ascend behavior 
behavior ascend
{
duration = 300;
horizontalMode = rudder;
horizontal = 3.000000;
pitch = 45.000000;
speed = 1.500000;
endDepth = 2.000000;
}
# 
# Acoustic update - sent status ping after end of survey 
# 
behavior acousticUpdate
{
duration = 2;
dummy = 1;
}
# 
#######################################################
# 
# 
# Waypoint behavior to get to end of line 1
#   Segment length 873.018200 meters
#   Minimum depth: 101.745921 meters looking forward 0.000000 meters along route
#   Maximum depth: 101.745921 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 112.970408 meters
#   Desired vehicle altitude: 10.000000 meters
#   Minimum vehicle altitude: 20.000000 meters
#   Behavior depth of 91.745921 meters set by local depth and desired altitude
#   Vehicle survey speed:     1.000000 m/s
behavior waypoint
{
latitude = 36.817854;
longitude = -121.834716;
duration = 2619;
depth = 60.;
speed = 1.500000;
}
# 
#######################################################
# 
# 
# Waypoint behavior during line 1
#   Segment length 501.484475 meters
#   Minimum depth: 66.842562 meters looking forward 0.000000 meters along route
#   Maximum depth: 66.842562 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 112.970408 meters
#   Desired vehicle altitude: 10.000000 meters
#   Minimum vehicle altitude: 20.000000 meters
#   Behavior depth of 56.842562 meters set by local depth and desired altitude
#   Vehicle survey speed:     1.000000 m/s
behavior waypoint
{
latitude = 36.817911;
longitude = -121.844503;
duration = 1504;
depth = 60.;
speed = 1.500000;
}
# 
#######################################################
# Acoustic update - sent status ping before start of line 
# 
behavior acousticUpdate
{
duration = 2;
dummy = 1;
}
# 
#######################################################
#######################################################
# 
# 
# Waypoint behavior to get to start of line 1
#   Segment length 0.000000 meters
#   Minimum depth: 122.970408 meters looking forward 0.000000 meters along route
#   Maximum depth: 122.970408 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 112.970408 meters
#   Desired vehicle altitude: 10.000000 meters
#   Minimum vehicle altitude: 20.000000 meters
#   Behavior depth of 112.970408 meters set by local depth and desired altitude
#   Vehicle survey speed:     1.000000 m/s
behavior waypoint
{
latitude = 36.817944;
longitude = -121.850125;
duration = 800;
depth = 60.;
speed = 1.500000;
}
#######################################################
# Acoustic update - sent status ping after end of line 
# 
behavior acousticUpdate
{
duration = 2;
dummy = 1;
}
# 
# 
#######################################################
#######################################################
# 
# 
# Descend behavior 
behavior descend
{
horizontalMode = heading;
horizontal = 284;
pitch = -30.000000;
speed = 1.500000;
maxDepth = 3.000000;
minAltitude = 20.000000;
duration = 300;
}
# 
# setpoint on surface to gather momentum 
behavior setpoint
{
duration = 30;
heading = 284;
speed = 1.500000;
verticalMode = pitch;
pitch = 0;
}
# 
# acquire gps fix 
behavior getgps
{
duration = 600;
minHits = 10;
abortOnTimeout = True;
}
#######################################################
#######################################################
