

# This MBARI Mapping AUV mission file has been generated
# by the MB-System program mbm_route2mission run by
# user <caress> on cpu <bluewater> at <Mon Nov 15 08:59:34 PST 2010>
# 
# Mission Summary:
#     Route File:               20101115_OaTest1.rte
#     Mission File:             20101115_OaTest1.cfg
#     Distance:                 4424.381268 (m)
#     Estimated Time:           5410 (s)  1.503 (hr)
#     Abort Time:               7033 (s)
#     Max battery life:         64800 (s)
#     Safety margin:            1800 (s)
#     Ascend time:              300 (s)
#     Way Points:               5
#     Route Points:             9
#     Survey behavior:          Waypoint
#     Descent style:            Waypoint descent
#     Mapping sonar control disabled:          
#     Benthic imaging camera control enabled:  
# 
# Mission Parameters:
#     Vehicle Survey Speed:     1.000000 (m/s) 1.943846 (knots)
#     Vehicle Ascent Speed:     1.500000 (m/s) 2.915769 (knots)
#     Vehicle Transit Speed:    1.500000 (m/s) 2.915769 (knots)
#     Desired Vehicle Altitude: 5 (m)
#     Minimum Vehicle Altitude: 10 (m)
#     Abort Vehicle Altitude:   3 (m)
#     Maximum Vehicle Depth:    115.897888 (m)
#     Abort Vehicle Depth:      120.897888 (m)
#     Descent Vehicle Depth:    3 (m)
#     Waypoint Spacing:         500 (m)
#     GPS Duration:             600 (s)
#     Descend Rate:             0.417 (m/s)
#     Ascend Rate:              1 (m/s)
#     Initial descend Duration: 300 (s)
#     Setpoint Duration:        30 (s)
# 
# The primary waypoints from the route file are:
#   <number> <longitude (deg)> <latitude (deg)> <topography (m)> <distance (m)> <type>
#   0 -121.834755 36.826200 -58.166245 0.000000 1
#   1 -121.835016 36.817877 -102.633846 923.685997 1
#   2 -121.849911 36.817967 -120.897888 2252.349921 1
#   3 -121.849911 36.826440 -75.085823 3192.381030 1
#   4 -121.836099 36.826290 -57.408075 4424.381268 1
# 
# A total of 9 mission points have been defined.
# 
# Define Mission parameters:
# 
#######################################################
# Set Mission Behaviors
# 
# mission timer set to 120% of estimated time of mission
behavior missionTimer
{
timeOut = 3600;
}
# 
# depth envelope
behavior depthEnvelope
{
minDepth = 0;
maxDepth = 115.897888;
abortDepth = 120.897888;
minAltitude = 20.000000;
abortAltitude = 10.000000;
}
#######################################################
# Set End-of-Mission Behaviors
# 
# 
# acquire gps fix 
behavior getgps
{
duration = 600;
minHits = 10;
abortOnTimeout = True;
}
# 
# ascend behavior 
behavior ascend
{
duration = 300;
horizontalMode = rudder;
horizontal = 3.000000;
pitch = 45.000000;
speed = 1.500000;
endDepth = 2.000000;
}
# 
# Acoustic update - sent status ping after end of survey 
# 
behavior acousticUpdate
{
duration = 2;
dummy = 1;
}
# 
# Turn off camera imaging 
#   Distance along survey: 4424.381268
#behavior stopCamera 
#{ 
#duration  = 1; 
#} 
#######################################################
# 
# 
# Waypoint behavior to get to end of line 4
#   Segment length 725.872929 meters
#   Minimum depth: 57.408075 meters looking forward 0.000000 meters along route
#   Maximum depth: 57.408075 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 115.897888 meters
#   Desired vehicle altitude: 5.000000 meters
#   Minimum vehicle altitude: 10.000000 meters
#   Behavior depth of 52.408075 meters set by local depth and desired altitude
behavior waypoint
{
latitude = 36.826290;
longitude = -121.836099;
duration = 2177;
# abortOnTimeout    = True; 
depth = 20.0;
speed = 1.500000;
}
# 
#######################################################
# 
# 
# Waypoint behavior during line 4
#   Segment length 506.127309 meters
#   Minimum depth: 58.399051 meters looking forward 0.000000 meters along route
#   Maximum depth: 58.399051 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 115.897888 meters
#   Desired vehicle altitude: 5.000000 meters
#   Minimum vehicle altitude: 10.000000 meters
#   Behavior depth of 53.399051 meters set by local depth and desired altitude
behavior waypoint
{
latitude = 36.826378;
longitude = -121.844237;
duration = 1518;
depth = 20.0;
speed = 1.500000;
}
# 
#######################################################
# 
# 
# Waypoint behavior to get to end of line 3
#   Segment length 433.343494 meters
#   Minimum depth: 75.085823 meters looking forward 0.000000 meters along route
#   Maximum depth: 75.085823 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 115.897888 meters
#   Desired vehicle altitude: 5.000000 meters
#   Minimum vehicle altitude: 10.000000 meters
#   Behavior depth of 70.085823 meters set by local depth and desired altitude
behavior waypoint
{
latitude = 36.826440;
longitude = -121.849911;
duration = 1300;
# abortOnTimeout    = True; 
depth = 20.0;
speed = 1.500000;
}
# 
#######################################################
# 
# 
# Waypoint behavior during line 3
#   Segment length 506.687615 meters
#   Minimum depth: 96.675442 meters looking forward 0.000000 meters along route
#   Maximum depth: 96.675442 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 115.897888 meters
#   Desired vehicle altitude: 5.000000 meters
#   Minimum vehicle altitude: 10.000000 meters
#   Behavior depth of 91.675442 meters set by local depth and desired altitude
behavior waypoint
{
latitude = 36.822534;
longitude = -121.849911;
duration = 1520;
depth = 20.0;
speed = 1.500000;
}
# 
#######################################################
# 
# 
# Waypoint behavior to get to end of line 2
#   Segment length 825.830764 meters
#   Minimum depth: 120.897888 meters looking forward 0.000000 meters along route
#   Maximum depth: 120.897888 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 115.897888 meters
#   Desired vehicle altitude: 5.000000 meters
#   Minimum vehicle altitude: 10.000000 meters
#   Behavior depth of 115.897888 meters set by local depth and desired altitude
behavior waypoint
{
latitude = 36.817967;
longitude = -121.849911;
duration = 2477;
# abortOnTimeout    = True; 
depth = 50.0;
speed = 1.0;
}
# 
#######################################################
# 
# 
# Waypoint behavior during line 2
#   Segment length 502.833160 meters
#   Minimum depth: 94.776865 meters looking forward 0.000000 meters along route
#   Maximum depth: 94.776865 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 115.897888 meters
#   Desired vehicle altitude: 5.000000 meters
#   Minimum vehicle altitude: 10.000000 meters
#   Behavior depth of 89.776865 meters set by local depth and desired altitude
behavior waypoint
{
latitude = 36.817911;
longitude = -121.840653;
duration = 1508;
depth = 50.0;
speed = 1.0;
}
# 
#######################################################
# 
# 
# Waypoint behavior to get to end of line 1
#   Segment length 416.800920 meters
#   Minimum depth: 102.633846 meters looking forward 0.000000 meters along route
#   Maximum depth: 102.633846 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 115.897888 meters
#   Desired vehicle altitude: 5.000000 meters
#   Minimum vehicle altitude: 10.000000 meters
#   Behavior depth of 97.633846 meters set by local depth and desired altitude
behavior waypoint
{
latitude = 36.817877;
longitude = -121.835016;
duration = 1250;
# abortOnTimeout    = True; 
depth = 20.0;
speed = 1.500000;
}
# 
#######################################################
# 
# 
# Waypoint behavior during line 1
#   Segment length 506.885077 meters
#   Minimum depth: 86.693625 meters looking forward 0.000000 meters along route
#   Maximum depth: 86.693625 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 115.897888 meters
#   Desired vehicle altitude: 5.000000 meters
#   Minimum vehicle altitude: 10.000000 meters
#   Behavior depth of 81.693625 meters set by local depth and desired altitude
behavior waypoint
{
latitude = 36.821633;
longitude = -121.834898;
duration = 1520;
depth = 20.0;
speed = 1.500000;
}
# 
#######################################################
# 
# 
# Waypoint behavior to get to start of line 1
#   Segment length 0.000000 meters
#   Minimum depth: 58.166245 meters looking forward 0.000000 meters along route
#   Maximum depth: 58.166245 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 115.897888 meters
#   Desired vehicle altitude: 5.000000 meters
#   Minimum vehicle altitude: 10.000000 meters
#   Behavior depth of 53.166245 meters set by local depth and desired altitude
behavior waypoint
{
latitude = 36.826200;
longitude = -121.834755;
duration = 600;
depth = 20.0;
speed = 1.500000;
}
# 
#######################################################
#######################################################
# 
# 
# Descend behavior 
behavior descend
{
horizontalMode = heading;
horizontal = 246.0;
pitch = -30.000000;
speed = 1.500000;
maxDepth = 3.000000;
minAltitude = 20.000000;
duration = 300;
}
# 
# setpoint on surface to gather momentum 
behavior setpoint
{
duration = 30;
heading = 246.0;
speed = 1.500000;
verticalMode = pitch;
pitch = 0;
}
# 
# acquire gps fix 
behavior getgps
{
duration = 600;
minHits = 10;
abortOnTimeout = True;
}
#######################################################
#######################################################
