

# This MBARI Mapping AUV mission file has been generated
# by the MB-System program mbm_route2mission run by
# user <caress> on cpu <autonomo> at <Mon Nov 29 14:02:34 PST 2010>
# 
# Mission Summary:
#     Route File:               20101130_OaTest3.rte
#     Mission File:             20101130_OaTest3.cfg
#     Distance:                 1753.039256 (m)
#     Estimated Time:           2386 (s)  0.663 (hr)
#     Abort Time:               3102 (s)
#     Max battery life:         64800 (s)
#     Safety margin:            1800 (s)
#     Ascend time:              341 (s)
#     Way Points:               5
#     Route Points:             5
#     Survey behavior:          WaypointDepth
#     Descent style:            Waypoint descent
#     Mapping sonar control disabled:          
#     Benthic imaging camera control enabled:  
# 
# Mission Parameters:
#     Vehicle Survey Speed:     1.500000 (m/s) 2.915769 (knots)
#     Vehicle Ascent Speed:     1.500000 (m/s) 2.915769 (knots)
#     Vehicle Transit Speed:    1.500000 (m/s) 2.915769 (knots)
#     Desired Vehicle Altitude: 0 (m)
#     Minimum Vehicle Altitude: 10 (m)
#     Abort Vehicle Altitude:   5 (m)
#     Delta Depth Restart:      5 (m)
#     Maximum Vehicle Depth:    279.512044 (m)
#     Abort Vehicle Depth:      284.512044 (m)
#     Descent Vehicle Depth:    3 (m)
#     Waypoint Spacing:         10000 (m)
#     GPS Duration:             600 (s)
#     Descend Rate:             0.417 (m/s)
#     Ascend Rate:              1 (m/s)
#     Initial descend Duration: 300 (s)
#     Setpoint Duration:        30 (s)
# 
# The primary waypoints from the route file are:
#   <number> <longitude (deg)> <latitude (deg)> <topography (m)> <distance (m)> <type>
#   0 -121.840375 36.801449 -81.765299 0.000000 3
#   1 -121.848127 36.801344 -195.307393 691.644751 1
#   2 -121.852422 36.799286 -278.530843 1137.774973 1
#   3 -121.855784 36.797799 -278.281962 1480.118935 1
#   4 -121.858474 36.796627 -284.512044 1753.039256 4
# 
# A total of 5 mission points have been defined.
# 
# Define Mission parameters:
# 
#######################################################
# Set Mission Behaviors
# 
# mission timer set to 120% of estimated time of mission
behavior missionTimer
{
timeOut = 3102;
}
# 
# depth envelope
behavior depthEnvelope
{
minDepth = 0;
maxDepth = 279.512044;
abortDepth = 284.512044;
minAltitude = 10.000000;
abortAltitude = 5.000000;
deltaDepthRestart = 5.000000;
}
#######################################################
# Set End-of-Mission Behaviors
# 
# 
# acquire gps fix 
behavior getgps
{
duration = 600;
minHits = 10;
abortOnTimeout = True;
}
# 
# ascend behavior 
behavior ascend
{
duration = 341;
horizontalMode = rudder;
horizontal = 3.000000;
pitch = 45.000000;
speed = 1.500000;
endDepth = 2.000000;
}
# 
# Acoustic update - sent status ping after end of survey 
# 
behavior acousticUpdate
{
duration = 2;
dummy = 1;
}
# 
# Turn off camera imaging 
#   Distance along survey: 1753.039256
#behavior stopCamera 
#{ 
#duration  = 1; 
#} 
#######################################################
# 
# 
# Waypoint_depth behavior to get to end of line 4
#   Segment length 272.920321 meters
#   Minimum depth: 284.512044 meters looking forward 0.000000 meters along route
#   Maximum depth: 284.512044 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 279.512044 meters
#   Desired vehicle altitude: 0.000000 meters
#   Minimum vehicle altitude: 10.000000 meters
#   Behavior depth of 279.512044 meters set to maximum vehicle depth
#   Vehicle survey speed:     1.500000 m/s
behavior waypoint_depth
{
latitude = 36.796627;
longitude = -121.858474;
duration = 545;
# abortOnTimeout    = True; 
initialDepth = 278.281962;
finalDepth = 279.512044;
maxCrossTrackError = 30;
speed = 1.500000;
}
# 
#######################################################
#######################################################
# 
# 
# Waypoint_depth behavior to get to end of line 3
#   Segment length 342.343962 meters
#   Minimum depth: 278.281962 meters looking forward 0.000000 meters along route
#   Maximum depth: 278.281962 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 279.512044 meters
#   Desired vehicle altitude: 0.000000 meters
#   Minimum vehicle altitude: 10.000000 meters
#   Behavior depth of 278.281962 meters set by local depth and desired altitude
#   Vehicle survey speed:     1.500000 m/s
behavior waypoint_depth
{
latitude = 36.797799;
longitude = -121.855784;
duration = 684;
# abortOnTimeout    = True; 
initialDepth = 278.530843;
finalDepth = 278.281962;
maxCrossTrackError = 30;
speed = 1.500000;
}
# 
#######################################################
#######################################################
# 
# 
# Waypoint_depth behavior to get to end of line 2
#   Segment length 446.130222 meters
#   Minimum depth: 278.530843 meters looking forward 0.000000 meters along route
#   Maximum depth: 278.530843 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 279.512044 meters
#   Desired vehicle altitude: 0.000000 meters
#   Minimum vehicle altitude: 10.000000 meters
#   Behavior depth of 278.530843 meters set by local depth and desired altitude
#   Vehicle survey speed:     1.500000 m/s
behavior waypoint_depth
{
latitude = 36.799286;
longitude = -121.852422;
duration = 892;
# abortOnTimeout    = True; 
initialDepth = 195.307393;
finalDepth = 278.530843;
maxCrossTrackError = 30;
speed = 1.500000;
}
# 
#######################################################
#######################################################
# 
# 
# Waypoint_depth behavior to get to end of line 1
#   Segment length 691.644751 meters
#   Minimum depth: 195.307393 meters looking forward 0.000000 meters along route
#   Maximum depth: 195.307393 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 279.512044 meters
#   Desired vehicle altitude: 0.000000 meters
#   Minimum vehicle altitude: 10.000000 meters
#   Behavior depth of 195.307393 meters set by local depth and desired altitude
#   Vehicle survey speed:     1.500000 m/s
behavior waypoint_depth
{
latitude = 36.801344;
longitude = -121.848127;
duration = 1383;
# abortOnTimeout    = True; 
initialDepth = 81.765299;
finalDepth = 195.307393;
maxCrossTrackError = 30;
speed = 1.500000;
}
# 
#######################################################
# Start taking pictures with camera.
#   Distance along survey: 0.000000
#   Length of camera run: 1753.039256
#   Number of photos: 192
#behavior startCamera 
#{ 
#duration  = 1; 
#nSamplePeriods = 9; 
#} 
# 
#######################################################
# Acoustic update - sent status ping before start of line 
# 
behavior acousticUpdate
{
duration = 2;
dummy = 1;
}
# 
#######################################################
#######################################################
#######################################################
# 
# 
# Waypoint_depth behavior to get to start of line 1
#   Segment length 0.000000 meters
#   Minimum depth: 81.765299 meters looking forward 0.000000 meters along route
#   Maximum depth: 81.765299 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 279.512044 meters
#   Desired vehicle altitude: 0.000000 meters
#   Minimum vehicle altitude: 10.000000 meters
#   Behavior depth of 81.765299 meters set by local depth and desired altitude
#   Vehicle survey speed:     1.500000 m/s
behavior waypoint_depth
{
latitude = 36.801449;
longitude = -121.840375;
duration = 600;
initialDepth = 81.765299;
finalDepth = 81.765299;
maxCrossTrackError = 30;
speed = 1.500000;
}
#######################################################
# Acoustic update - sent status ping after end of line 
# 
behavior acousticUpdate
{
duration = 2;
dummy = 1;
}
# 
# 
#######################################################
#######################################################
# 
# 
# Descend behavior 
behavior descend
{
horizontalMode = heading;
horizontal = 268.341092;
pitch = -30.000000;
speed = 1.500000;
maxDepth = 3.000000;
minAltitude = 10.000000;
duration = 300;
}
# 
# setpoint on surface to gather momentum 
behavior setpoint
{
duration = 30;
heading = 268.341092;
speed = 1.500000;
verticalMode = pitch;
pitch = 0;
}
# 
# acquire gps fix 
behavior getgps
{
duration = 600;
minHits = 10;
abortOnTimeout = True;
}
#######################################################
#######################################################
