

################################################################################
#
# PURPOSE: Test operational speed range of the vehicle.
# AUTHOR:  Gashler, McEwen
# DATE:    02/17/2003:
# NOTE:    Sequential behavoirs are bottom-up.  Priorities are top-down.
# MODS:
#
################################################################################







#
behavior missionTimer
{
  timeOut = 1500;
}
#
# Depth Envelope
#
behavior depthEnvelope
{
  minDepth = 0; #Meters
  maxDepth = 45; #Meters
  minAltitude = 5; #Meters
  abortDepth = 50; #Meters
}

behavior getgps
{
  minHits = 10;
  duration = 60;
}

behavior ascend
{

  duration = 180; #Seconds
  horizontalMode = heading; #Mode
  horizontal = 300; #Degrees; 
  pitch = 45; #Degrees
  speed = 1.0;
  endDepth = 2; #Meters
}
#
# Command a constant heading and depth.
#
behavior setpoint
{
  duration = 400;
  heading = 300;
  speed = 1.0;
  verticalMode = depth;
  depth = 40; #Meters
}
#
# Command a constant heading and depth.
#
behavior setpoint
{
  duration = 400;
  heading = 300;
  speed = 1.0;
  verticalMode = depth;
  depth = 30; #Meters
}
#
# Command a constant heading and depth.
#
behavior setpoint
{
  duration = 200;
  heading = 300;
  speed = 1.0;
  verticalMode = depth;
  depth = 20; #Meters
}
#
# Command a constant heading and depth.
#
behavior setpoint
{
  duration = 200;
  heading = 300;
  speed = 1.5;
  verticalMode = depth;
  depth = 20; #Meters
}

# descend behavior for launch

behavior descend
{
  duration = 90;
  horizontalMode = heading;
  horizontal = 300;
  pitch = -10;
  speed = 1.5;
  maxDepth = 17;
  minAltitude = 10;
}

# setpoint on surface to accelerate to speed.

behavior setpoint
{
  duration = 30;
  heading = 300;
  speed = 1.5;
  verticalMode = pitch;
  pitch = 0;
}

behavior getgps
{
  minHits = 10;
  duration = 60;
  abortOnTimeout = True;
}
