

# This MBARI Mapping AUV mission file has been generated
# by the MB-System program mbm_route2mission run by
# user <caress> on cpu <Ewing> at <Tue Nov 16 11:20:56 PST 2010>
# 
# Mission Summary:
#     Route File:               20101115_OaTest2v2.rte
#     Mission File:             20101115_OaTest2v2.cfg
#     Distance:                 954.004788 (m)
#     Estimated Time:           1949 (s)  0.542 (hr)
#     Abort Time:               2534 (s)
#     Max battery life:         64800 (s)
#     Safety margin:            1800 (s)
#     Ascend time:              300 (s)
#     Way Points:               16
#     Route Points:             16
#     Survey behavior:          Waypoint
#     Descent style:            Waypoint descent
#     Mapping sonar control disabled:          
#     Benthic imaging camera control enabled:  
# 
# Mission Parameters:
#     Vehicle Survey Speed:     1.500000 (m/s) 1.943846 (knots)
#     Vehicle Ascent Speed:     1.500000 (m/s) 2.915769 (knots)
#     Vehicle Transit Speed:    1.500000 (m/s) 2.915769 (knots)
#     Desired Vehicle Altitude: 0 (m)
#     Minimum Vehicle Altitude: 3 (m)
#     Abort Vehicle Altitude:   1 (m)
#     Delta Depth Restart:      1.5 (m)
#     Maximum Vehicle Depth:    61.679797 (m)
#     Abort Vehicle Depth:      63.179797 (m)
#     Descent Vehicle Depth:    3 (m)
#     Waypoint Spacing:         500 (m)
#     GPS Duration:             600 (s)
#     Descend Rate:             0.417 (m/s)
#     Ascend Rate:              1 (m/s)
#     Initial descend Duration: 300 (s)
#     Setpoint Duration:        30 (s)
# 
# The primary waypoints from the route file are:
#   <number> <longitude (deg)> <latitude (deg)> <topography (m)> <distance (m)> <type>
#   0 -121.844065 36.822839 -62.771558 0.000000 3
#   1 -121.844065 36.821929 -63.179797 100.959455 4
#   2 -121.843841 36.821929 -62.817920 120.939092 3
#   3 -121.843841 36.822839 -62.536517 221.898553 4
#   4 -121.844043 36.822844 -62.702309 239.924228 3
#   5 -121.844043 36.821924 -63.103848 341.993128 4
#   6 -121.843819 36.821924 -62.779862 361.972767 3
#   7 -121.843819 36.822844 -62.322256 464.041673 4
#   8 -121.844020 36.822848 -62.702309 481.975107 3
#   9 -121.844020 36.821920 -63.103848 584.931564 4
#   10 -121.843796 36.821920 -62.779862 604.911203 3
#   11 -121.843796 36.822848 -62.322256 707.867665 4
#   12 -121.843998 36.822853 -62.674642 725.893338 3
#   13 -121.843998 36.821915 -63.050018 829.959240 4
#   14 -121.843774 36.821915 -62.782717 849.938881 3
#   15 -121.843774 36.822853 -62.240613 954.004788 4
# 
# A total of 16 mission points have been defined.
# 
# Define Mission parameters:
# 
#######################################################
# Set Mission Behaviors
# 
# mission timer set to 120% of estimated time of mission
behavior missionTimer
{
timeOut = 2400;
}
# 
# depth envelope
behavior depthEnvelope
{
minDepth = 0;
maxDepth = 61.679797;
abortDepth = 63.179797;
minAltitude = 3.000000;
abortAltitude = 1.000000;
deltaDepthRestart = 1.500000;
}
#######################################################
# Set End-of-Mission Behaviors
# 
# 
# acquire gps fix 
behavior getgps
{
duration = 600;
minHits = 10;
abortOnTimeout = True;
}
# 
# ascend behavior 
behavior ascend
{
duration = 300;
horizontalMode = rudder;
horizontal = 3.000000;
pitch = 45.000000;
speed = 1.500000;
endDepth = 2.000000;
}
# 
# Acoustic update - sent status ping after end of survey 
# 
behavior acousticUpdate
{
duration = 2;
dummy = 1;
}
# 
# Turn off camera imaging 
#   Distance along survey: 954.004788
behavior stopCamera
{
duration = 1;
}
#######################################################
# 
# 
# Waypoint behavior to get to end of line 15
#   Segment length 104.065907 meters
#   Minimum depth: 62.240613 meters looking forward 0.000000 meters along route
#   Maximum depth: 62.240613 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 61.679797 meters
#   Desired vehicle altitude: 0.000000 meters
#   Minimum vehicle altitude: 3.000000 meters
#   Behavior depth of 61.679797 meters set to maximum vehicle depth
#   Vehicle survey speed:     1.000000 m/s
behavior waypoint
{
latitude = 36.822853;
longitude = -121.843774;
duration = 312;
# abortOnTimeout    = True; 
depth = 61.679797;
speed = 1.500000;
}
# 
#######################################################
# Start taking pictures with camera.
#   Distance along survey: 849.938881
#   Length of camera run: 104.065907
#   Number of photos: 11
behavior startCamera
{
duration = 1;
nSamplePeriods = 9;
}
# 
#######################################################
# Acoustic update - sent status ping before start of line 
# 
behavior acousticUpdate
{
duration = 2;
dummy = 1;
}
# 
#######################################################
#######################################################
#######################################################
# 
# 
# Waypoint behavior to get to end of line 14
#   Segment length 19.979641 meters
#   Minimum depth: 62.782717 meters looking forward 0.000000 meters along route
#   Maximum depth: 62.782717 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 61.679797 meters
#   Desired vehicle altitude: 0.000000 meters
#   Minimum vehicle altitude: 3.000000 meters
#   Behavior depth of 61.679797 meters set to maximum vehicle depth
#   Vehicle transit speed:    1.500000 m/s
behavior waypoint
{
latitude = 36.821915;
longitude = -121.843774;
duration = 59;
# abortOnTimeout    = True; 
depth = 61.679797;
speed = 1.500000;
}
#######################################################
# Acoustic update - sent status ping after end of line 
# 
behavior acousticUpdate
{
duration = 2;
dummy = 1;
}
# 
# 
#######################################################
# Stop taking pictures with camera.
#   Distance along survey: 829.959240
behavior stopCamera
{
duration = 1;
}
# 
#######################################################
#######################################################
#######################################################
# 
# 
# Waypoint behavior to get to end of line 13
#   Segment length 104.065902 meters
#   Minimum depth: 63.050018 meters looking forward 0.000000 meters along route
#   Maximum depth: 63.050018 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 61.679797 meters
#   Desired vehicle altitude: 0.000000 meters
#   Minimum vehicle altitude: 3.000000 meters
#   Behavior depth of 61.679797 meters set to maximum vehicle depth
#   Vehicle survey speed:     1.000000 m/s
behavior waypoint
{
latitude = 36.821915;
longitude = -121.843998;
duration = 312;
# abortOnTimeout    = True; 
depth = 61.679797;
speed = 1.500000;
}
# 
#######################################################
# Start taking pictures with camera.
#   Distance along survey: 725.893338
#   Length of camera run: 104.065902
#   Number of photos: 11
behavior startCamera
{
duration = 1;
nSamplePeriods = 9;
}
# 
#######################################################
# Acoustic update - sent status ping before start of line 
# 
behavior acousticUpdate
{
duration = 2;
dummy = 1;
}
# 
#######################################################
#######################################################
#######################################################
# 
# 
# Waypoint behavior to get to end of line 12
#   Segment length 18.025673 meters
#   Minimum depth: 62.674642 meters looking forward 0.000000 meters along route
#   Maximum depth: 62.674642 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 61.679797 meters
#   Desired vehicle altitude: 0.000000 meters
#   Minimum vehicle altitude: 3.000000 meters
#   Behavior depth of 61.679797 meters set to maximum vehicle depth
#   Vehicle transit speed:    1.500000 m/s
behavior waypoint
{
latitude = 36.822853;
longitude = -121.843998;
duration = 54;
# abortOnTimeout    = True; 
depth = 61.679797;
speed = 1.500000;
}
#######################################################
# Acoustic update - sent status ping after end of line 
# 
behavior acousticUpdate
{
duration = 2;
dummy = 1;
}
# 
# 
#######################################################
# Stop taking pictures with camera.
#   Distance along survey: 707.867665
behavior stopCamera
{
duration = 1;
}
# 
#######################################################
#######################################################
#######################################################
# 
# 
# Waypoint behavior to get to end of line 11
#   Segment length 102.956462 meters
#   Minimum depth: 62.322256 meters looking forward 0.000000 meters along route
#   Maximum depth: 62.322256 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 61.679797 meters
#   Desired vehicle altitude: 0.000000 meters
#   Minimum vehicle altitude: 3.000000 meters
#   Behavior depth of 61.679797 meters set to maximum vehicle depth
#   Vehicle survey speed:     1.000000 m/s
behavior waypoint
{
latitude = 36.822848;
longitude = -121.843796;
duration = 308;
# abortOnTimeout    = True; 
depth = 61.679797;
speed = 1.500000;
}
# 
#######################################################
# Start taking pictures with camera.
#   Distance along survey: 604.911203
#   Length of camera run: 102.956462
#   Number of photos: 11
behavior startCamera
{
duration = 1;
nSamplePeriods = 9;
}
# 
#######################################################
# Acoustic update - sent status ping before start of line 
# 
behavior acousticUpdate
{
duration = 2;
dummy = 1;
}
# 
#######################################################
#######################################################
#######################################################
# 
# 
# Waypoint behavior to get to end of line 10
#   Segment length 19.979639 meters
#   Minimum depth: 62.779862 meters looking forward 0.000000 meters along route
#   Maximum depth: 62.779862 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 61.679797 meters
#   Desired vehicle altitude: 0.000000 meters
#   Minimum vehicle altitude: 3.000000 meters
#   Behavior depth of 61.679797 meters set to maximum vehicle depth
#   Vehicle transit speed:    1.500000 m/s
behavior waypoint
{
latitude = 36.821920;
longitude = -121.843796;
duration = 59;
# abortOnTimeout    = True; 
depth = 61.679797;
speed = 1.500000;
}
#######################################################
# Acoustic update - sent status ping after end of line 
# 
behavior acousticUpdate
{
duration = 2;
dummy = 1;
}
# 
# 
#######################################################
# Stop taking pictures with camera.
#   Distance along survey: 584.931564
behavior stopCamera
{
duration = 1;
}
# 
#######################################################
#######################################################
#######################################################
# 
# 
# Waypoint behavior to get to end of line 9
#   Segment length 102.956457 meters
#   Minimum depth: 63.103848 meters looking forward 0.000000 meters along route
#   Maximum depth: 63.103848 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 61.679797 meters
#   Desired vehicle altitude: 0.000000 meters
#   Minimum vehicle altitude: 3.000000 meters
#   Behavior depth of 61.679797 meters set to maximum vehicle depth
#   Vehicle survey speed:     1.000000 m/s
behavior waypoint
{
latitude = 36.821920;
longitude = -121.844020;
duration = 308;
# abortOnTimeout    = True; 
depth = 61.679797;
speed = 1.500000;
}
# 
#######################################################
# Start taking pictures with camera.
#   Distance along survey: 481.975107
#   Length of camera run: 102.956457
#   Number of photos: 11
behavior startCamera
{
duration = 1;
nSamplePeriods = 9;
}
# 
#######################################################
# Acoustic update - sent status ping before start of line 
# 
behavior acousticUpdate
{
duration = 2;
dummy = 1;
}
# 
#######################################################
#######################################################
#######################################################
# 
# 
# Waypoint behavior to get to end of line 8
#   Segment length 17.933434 meters
#   Minimum depth: 62.702309 meters looking forward 0.000000 meters along route
#   Maximum depth: 62.702309 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 61.679797 meters
#   Desired vehicle altitude: 0.000000 meters
#   Minimum vehicle altitude: 3.000000 meters
#   Behavior depth of 61.679797 meters set to maximum vehicle depth
#   Vehicle transit speed:    1.500000 m/s
behavior waypoint
{
latitude = 36.822848;
longitude = -121.844020;
duration = 53;
# abortOnTimeout    = True; 
depth = 61.679797;
speed = 1.500000;
}
#######################################################
# Acoustic update - sent status ping after end of line 
# 
behavior acousticUpdate
{
duration = 2;
dummy = 1;
}
# 
# 
#######################################################
# Stop taking pictures with camera.
#   Distance along survey: 464.041673
behavior stopCamera
{
duration = 1;
}
# 
#######################################################
#######################################################
#######################################################
# 
# 
# Waypoint behavior to get to end of line 7
#   Segment length 102.068906 meters
#   Minimum depth: 62.322256 meters looking forward 0.000000 meters along route
#   Maximum depth: 62.322256 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 61.679797 meters
#   Desired vehicle altitude: 0.000000 meters
#   Minimum vehicle altitude: 3.000000 meters
#   Behavior depth of 61.679797 meters set to maximum vehicle depth
#   Vehicle survey speed:     1.000000 m/s
behavior waypoint
{
latitude = 36.822844;
longitude = -121.843819;
duration = 306;
# abortOnTimeout    = True; 
depth = 61.679797;
speed = 1.500000;
}
# 
#######################################################
# Start taking pictures with camera.
#   Distance along survey: 361.972767
#   Length of camera run: 102.068906
#   Number of photos: 11
behavior startCamera
{
duration = 1;
nSamplePeriods = 9;
}
# 
#######################################################
# Acoustic update - sent status ping before start of line 
# 
behavior acousticUpdate
{
duration = 2;
dummy = 1;
}
# 
#######################################################
#######################################################
#######################################################
# 
# 
# Waypoint behavior to get to end of line 6
#   Segment length 19.979639 meters
#   Minimum depth: 62.779862 meters looking forward 0.000000 meters along route
#   Maximum depth: 62.779862 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 61.679797 meters
#   Desired vehicle altitude: 0.000000 meters
#   Minimum vehicle altitude: 3.000000 meters
#   Behavior depth of 61.679797 meters set to maximum vehicle depth
#   Vehicle transit speed:    1.500000 m/s
behavior waypoint
{
latitude = 36.821924;
longitude = -121.843819;
duration = 59;
# abortOnTimeout    = True; 
depth = 61.679797;
speed = 1.500000;
}
#######################################################
# Acoustic update - sent status ping after end of line 
# 
behavior acousticUpdate
{
duration = 2;
dummy = 1;
}
# 
# 
#######################################################
# Stop taking pictures with camera.
#   Distance along survey: 341.993128
behavior stopCamera
{
duration = 1;
}
# 
#######################################################
#######################################################
#######################################################
# 
# 
# Waypoint behavior to get to end of line 5
#   Segment length 102.068900 meters
#   Minimum depth: 63.103848 meters looking forward 0.000000 meters along route
#   Maximum depth: 63.103848 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 61.679797 meters
#   Desired vehicle altitude: 0.000000 meters
#   Minimum vehicle altitude: 3.000000 meters
#   Behavior depth of 61.679797 meters set to maximum vehicle depth
#   Vehicle survey speed:     1.000000 m/s
behavior waypoint
{
latitude = 36.821924;
longitude = -121.844043;
duration = 306;
# abortOnTimeout    = True; 
depth = 61.679797;
speed = 1.500000;
}
# 
#######################################################
# Start taking pictures with camera.
#   Distance along survey: 239.924228
#   Length of camera run: 102.0689
#   Number of photos: 11
behavior startCamera
{
duration = 1;
nSamplePeriods = 9;
}
# 
#######################################################
# Acoustic update - sent status ping before start of line 
# 
behavior acousticUpdate
{
duration = 2;
dummy = 1;
}
# 
#######################################################
#######################################################
#######################################################
# 
# 
# Waypoint behavior to get to end of line 4
#   Segment length 18.025675 meters
#   Minimum depth: 62.702309 meters looking forward 0.000000 meters along route
#   Maximum depth: 62.702309 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 61.679797 meters
#   Desired vehicle altitude: 0.000000 meters
#   Minimum vehicle altitude: 3.000000 meters
#   Behavior depth of 61.679797 meters set to maximum vehicle depth
#   Vehicle transit speed:    1.500000 m/s
behavior waypoint
{
latitude = 36.822844;
longitude = -121.844043;
duration = 54;
# abortOnTimeout    = True; 
depth = 61.679797;
speed = 1.500000;
}
#######################################################
# Acoustic update - sent status ping after end of line 
# 
behavior acousticUpdate
{
duration = 2;
dummy = 1;
}
# 
# 
#######################################################
# Stop taking pictures with camera.
#   Distance along survey: 221.898553
behavior stopCamera
{
duration = 1;
}
# 
#######################################################
#######################################################
#######################################################
# 
# 
# Waypoint behavior to get to end of line 3
#   Segment length 100.959461 meters
#   Minimum depth: 62.536517 meters looking forward 0.000000 meters along route
#   Maximum depth: 62.536517 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 61.679797 meters
#   Desired vehicle altitude: 0.000000 meters
#   Minimum vehicle altitude: 3.000000 meters
#   Behavior depth of 61.679797 meters set to maximum vehicle depth
#   Vehicle survey speed:     1.000000 m/s
behavior waypoint
{
latitude = 36.822839;
longitude = -121.843841;
duration = 302;
# abortOnTimeout    = True; 
depth = 61.679797;
speed = 1.500000;
}
# 
#######################################################
# Start taking pictures with camera.
#   Distance along survey: 120.939092
#   Length of camera run: 100.959461
#   Number of photos: 11
behavior startCamera
{
duration = 1;
nSamplePeriods = 9;
}
# 
#######################################################
# Acoustic update - sent status ping before start of line 
# 
behavior acousticUpdate
{
duration = 2;
dummy = 1;
}
# 
#######################################################
#######################################################
#######################################################
# 
# 
# Waypoint behavior to get to end of line 2
#   Segment length 19.979637 meters
#   Minimum depth: 62.817920 meters looking forward 0.000000 meters along route
#   Maximum depth: 62.817920 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 61.679797 meters
#   Desired vehicle altitude: 0.000000 meters
#   Minimum vehicle altitude: 3.000000 meters
#   Behavior depth of 61.679797 meters set to maximum vehicle depth
#   Vehicle transit speed:    1.500000 m/s
behavior waypoint
{
latitude = 36.821929;
longitude = -121.843841;
duration = 59;
# abortOnTimeout    = True; 
depth = 61.679797;
speed = 1.500000;
}
#######################################################
# Acoustic update - sent status ping after end of line 
# 
behavior acousticUpdate
{
duration = 2;
dummy = 1;
}
# 
# 
#######################################################
# Stop taking pictures with camera.
#   Distance along survey: 100.959455
behavior stopCamera
{
duration = 1;
}
# 
#######################################################
#######################################################
#######################################################
# 
# 
# Waypoint behavior to get to end of line 1
#   Segment length 100.959455 meters
#   Minimum depth: 63.179797 meters looking forward 0.000000 meters along route
#   Maximum depth: 63.179797 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 61.679797 meters
#   Desired vehicle altitude: 0.000000 meters
#   Minimum vehicle altitude: 3.000000 meters
#   Behavior depth of 61.679797 meters set to maximum vehicle depth
#   Vehicle survey speed:     1.000000 m/s
behavior waypoint
{
latitude = 36.821929;
longitude = -121.844065;
duration = 302;
# abortOnTimeout    = True; 
depth = 61.679797;
speed = 1.500000;
}
# 
#######################################################
# Start taking pictures with camera.
#   Distance along survey: 0.000000
#   Length of camera run: 100.959455
#   Number of photos: 11
behavior startCamera
{
duration = 1;
nSamplePeriods = 9;
}
# 
#######################################################
# Acoustic update - sent status ping before start of line 
# 
behavior acousticUpdate
{
duration = 2;
dummy = 1;
}
# 
#######################################################
#######################################################
#######################################################
# 
# 
# Waypoint behavior to get to start of line 1
#   Segment length 0.000000 meters
#   Minimum depth: 62.771558 meters looking forward 0.000000 meters along route
#   Maximum depth: 62.771558 meters looking forward 0.000000 meters along route
#   Maximum vehicle depth: 61.679797 meters
#   Desired vehicle altitude: 0.000000 meters
#   Minimum vehicle altitude: 3.000000 meters
#   Behavior depth of 61.679797 meters set to maximum vehicle depth
#   Vehicle survey speed:     1.000000 m/s
behavior waypoint
{
latitude = 36.822839;
longitude = -121.844065;
duration = 1400;
depth = 40;
speed = 1.500000;
}
#######################################################
# Acoustic update - sent status ping after end of line 
# 
behavior acousticUpdate
{
duration = 2;
dummy = 1;
}
# 
# 
#######################################################
#######################################################
# 
# 
# Descend behavior 
behavior descend
{
horizontalMode = heading;
horizontal = 46;
pitch = -30.000000;
speed = 1.500000;
maxDepth = 3.000000;
minAltitude = 3.000000;
duration = 300;
}
# 
# setpoint on surface to gather momentum 
behavior setpoint
{
duration = 30;
heading = 46;
speed = 1.500000;
verticalMode = pitch;
pitch = 0;
}
# 
# acquire gps fix 
behavior getgps
{
duration = 600;
minHits = 10;
abortOnTimeout = True;
}
#######################################################
#######################################################
